@@ -1,4 +1,4 @@
-import sys, shlex, string, copy, re, os, warnings
+import sys, string, copy, re, os, warnings
 from .colorprint import write 
 __all__ = ["command_line_options","NoTracebackError",  "set_up_no_traceback_error"]
 
@@ -11,6 +11,7 @@ warnings.formatwarning = custom_formatwarning
 
 class CommandLineOptions(dict):
     """ Subclass of dict designed to store options of the command line.
+
     Two differences with dict:
      - its representation looks good on screen
      - requesting a key which is absent returns None, instead of throwing an error
@@ -40,10 +41,17 @@ def set_up_no_traceback_error(set_on=True):
     """After this, raising NoTracebackError or its subclasses results in single error line, without traceback.
     Under the hood, replaces sys.excepthook
     
-    Args:
-     set_on (bool): normally True. Call this fn with set_on=False to restore the default sys.excepthook
+    Parameters
+    ----------
 
-    Returns: None
+    set_on : bool
+        normally this is set to True when the module is loaded.
+        Call this fn with set_on=False to restore the default sys.excepthook
+
+    Returns
+    -------
+    None
+        None
     """
     def excepthook_allowing_notraceback(type, value, traceback):
         if issubclass(type, NoTracebackError):              sys.exit(str(value))
@@ -63,36 +71,135 @@ def command_line_options(default_opt,
                          tolerated_regexp=[],
                          warning_extra=True,
                          advanced_help_msg={}):
-    """Fetches command line keys (e.g. -i ) and theirs arguments from the command line, and returns them after filling with default values
+    """Reads command line arguments and returns them after filling with default values
     
-    Args:
-    * default_opt (dict):      default arguments for all keys. Their value types also define the typing enforced on command line arguments
-         possible value types are int, float, str, bool (argument can be omitted), list (multiple args accepted)
-    + help_msg (str):          if -h | -help | --help is provided, this help is displayed and the script exits
-    + positional_keys (iter):  these keys will be associated, in order, to args with no explicit keys (e.g. script.py arg1 arg2)
-    + synonyms (dict):         add synonyms for keys; e.g. {'inputfile':'i',  'p':'param'}; the built-in {'help':'h'} is added
+    Here below, we refer to option names as *keys* (e.g. the "i" in "program.py -i inputfile" ),
+    and *arguments* for their argument (e.g. "inputfile" above).
+    
+    Parameters
+    ----------
+    
+    default_opt : dict
+        defines default arguments for all command lines keys. 
+        Their value types also define the typing enforced on command line arguments.
+        Possible value types are int, float, str, bool (whose argument can be omitted), list (multiple args accepted)
 
-    + tolerate_extra (bool):    normally any keys not found in default_opt raises an error; this allows to tolerate & accept unexpected keys
-    + tolerated_regexp (list):  define which unexpected keys to tolerate using regexp employed by module re
-    + warning_extra (bool):     when keys are tolerated (two previous fn args), normally a warning is printed; set to False to silence these
-    + advanced_help_msg (dict): dictionary defining specialized help messages displayed only when invoked as argument to -h
+    help_msg : str
+        if any of -h | -help | --help are  provided, this help message is displayed and the script exits
 
-    Returns: 
-     opt (CommandLineOpt):      dictionary like structure with structure key:arg
+    positional_keys : iterable
+        these keys will be associated, in order, to argumentss with no explicit keys (e.g. script.py arg1 arg2)
 
-  Examples:     
+    synonyms : dict
+        add synonyms for keys; e.g. if you use {'input':'i', 'p':'param'} then using -input or -i in the command line will be equivalent
+        note: the built-in {'help':'h'} is automatically added
 
-   command_line_options( default_opt={'i': 'input', 'o':'output', 'param':3} )
-    script.py -i file1  -o file2   # --> {'i':'file1', 'o':'file2', 'param':3}
-    script.py -i file1  -param -1  # --> {'i':'file1', 'o':'output', 'param':-1}   # note param is cast to int
+    tolerate_extra : bool
+        normally any key not found in default_opt raises an error; this allows to tolerate & accept unexpected keys
 
-   command_line_options( default_opt={'param':3, 'files':[]},  synonyms={'p':'param'})
-    script.py -files a b c d e -p 10   # --> {'files':['a', 'b', 'c', 'd', 'e'], 'param':10}  # note -p as synonym
+    tolerated_regexp : list
+        define which unexpected keys to tolerate using regexp syntax, employed by module re
 
-   command_line_options( default_opt={'i':'', 'o':'', 's':'', 'k':5.5},  positional_keys=['i', 'o'])
-    script.py -k 4.5 in out     # --> {'i':'in', 'o':'out', 's':'', 'k':4.5}   # positional args
-    script.py in out -k 10      # --> {'i':'in', 'o':'out', 's':'', 'k':10.0}  # this order also accepted  # note -k cast to float
-    script.py in -s "multi word str"   # --> {'i':'', 'o':'', 's':'multi char str', 'k':5.5}  # multiword string as arg
+    warning_extra : bool
+        when keys are tolerated (see two previous args), normally a warning is printed; set this to False to silence them
+    
+    advanced_help_msg : dict
+        dictionary defining specialized help messages, which are displayed only when invoked as argument to -h
+        e.g. if you run on the command line ' -h map ', and if within the script you had 
+        advanced_help_msg={'map':'map message'}, then 'map message' is displayed
+
+    Returns
+    -------
+    opt : CommandLineOpt
+        dictionary like object with structure key:arg, carrying command line options and, if not provided, default values
+
+    Examples
+    --------
+
+    **Example 1**
+
+    If you use this code in your python script:
+
+    .. code-block:: python
+
+        command_line_options( default_opt={'i': 'input', 'o':'output', 'param':3} ) 
+
+    Then, when your script is run with this command line (in bash or analogous):
+
+    .. code-block:: bash
+
+        script.py -i file1  -o file2   
+
+    
+    ... this will result in this dictionary returned by ``command_line_options``:
+
+    .. code-block:: python
+
+        {'i':'file1', 'o':'file2', 'param':3}
+
+    Different command line and resulting dictionary returned:
+    
+    .. code-block:: bash
+
+        script.py -i file1  -param -1  
+    
+    .. code-block:: python
+
+        {'i':'file1', 'o':'output', 'param':-1}   # note param is cast to int
+
+
+    **Example 2**
+
+    With::
+
+        command_line_options( default_opt={'param':3, 'files':[]},  synonyms={'p':'param'})
+
+    This command line:
+
+    .. code-block:: bash
+
+        script.py -files a b c d e -p 10
+
+    Results in::
+ 
+        {'files':['a', 'b', 'c', 'd', 'e'], 'param':10}  # note -p as synonym
+
+
+    **Example 3**
+
+    With::
+
+        command_line_options( default_opt={'i':'', 'o':'', 's':'', 'k':5.5},  positional_keys=['i', 'o'])
+
+    This command line:
+
+    .. code-block:: bash
+
+        script.py -k 4.5 in1 out1    
+    
+    Results in::
+
+        {'i':'in1', 'o':'out1', 's':'', 'k':4.5}   # positional args
+
+    While this command line:
+
+    .. code-block:: bash
+
+        script.py in1 out1 -k 10      
+
+    Results in::
+
+        {'i':'in1', 'o':'out1', 's':'', 'k':10.0}  # this order also accepted  # note -k cast to float
+
+    And this command line:
+
+    .. code-block:: bash
+
+        script.py in1 -s "multi word str"   
+
+    Results in::
+
+        {'i':'in1', 'o':'', 's':'multi char str', 'k':5.5}  # multiword string as arg
     """
     
     default_opt=CommandLineOptions(default_opt)
@@ -227,10 +334,17 @@ def command_line_options(default_opt,
                 if expected_type is None:  # if this option was not in default_opt, we cast it to string (unless it had no argument, in which case to bool)
                     expected_type=str
                 if expected_type is bool:
-                    if   arglist[i+1]=='1':
+                    if   arglist[i+1] in ('1', 'T', 'True'):
                         value=True
-                    elif arglist[i+1]=='0':
+                    elif arglist[i+1] in ('0', 'F', 'False'):
                         value=False
+                    elif opt_key=='h':
+                        if not advanced_help_msg:
+                            raise CommandLineError(f"ERROR option -h does not accept arguments. Received: {arglist[i+1]}") from None
+                        elif not arglist[i+1] in advanced_help_msg:
+                            raise CommandLineError(f"ERROR argument {arglist[i+1]} is not accepted by option -h. Possible values: {' '.join(advanced_help_msg.keys())}") from None
+                        else:
+                            value=arglist[i+1] ## accepting non-bool value for -h
                     else:
                         raise CommandLineError(f"ERROR boolean options can only take values 0, 1 or none. Received: -{opt_key} : {arglist[i+1]}") from None
                 else:
@@ -252,7 +366,7 @@ def command_line_options(default_opt,
     if opt['h']:
         write(help_msg)        
         if advanced_help_msg and opt['h'] in advanced_help_msg:            
-            write(advanced[opt['h']])
+            write(advanced_help_msg[opt['h']])
             
     if opt['print_opt']:
         write(opt)
